@@ -4,7 +4,7 @@
 
 /*!
 
-# Encoding 0.2.20
+# Encoding 0.2.21
 
 Character encoding support for Rust. (also known as `rust-encoding`)
 It is based on [WHATWG Encoding Standard](http://encoding.spec.whatwg.org/),
@@ -173,7 +173,7 @@ Whenever in doubt, look at the source code and specifications for detailed expla
 */
 
 #![feature(core, collections)] // lib stability features as per RFC #507
-#![cfg_attr(test, feature(path, os, io, test))] // ditto
+#![cfg_attr(test, feature(path, env, io, test))] // ditto
 
 extern crate "encoding-index-singlebyte" as index_singlebyte;
 extern crate "encoding-index-korean" as index_korean;
